rename RPMSetPoint to SetPoint

The PIDs were originally focused on collecting RPM set points from
thermal PIDs and then having fan PIDs use the highest value collected,
it doesn't need to be strictly an RPM set point.

It does however need to be one type of value.

Signed-off-by: Patrick Venture <venture@google.com>
Change-Id: I1d589cf4b2688d7e86030c10496d737dc5bbdadf
diff --git a/test/pid_zone_unittest.cpp b/test/pid_zone_unittest.cpp
index 269b3f8..e0ecd76 100644
--- a/test/pid_zone_unittest.cpp
+++ b/test/pid_zone_unittest.cpp
@@ -121,7 +121,7 @@
 
 TEST_F(PidZoneTest, RpmSetPoints_AddMaxClear_BehaveAsExpected)
 {
     // Tests addRPMSetPoint, clearRPMSetPoints, determineMaxRPMRequest
     // and getMinThermalRPMSetpoint.
 
     // At least one value must be above the minimum thermal setpoint used in
@@ -129,7 +129,7 @@
     std::vector<double> values = {100, 200, 300, 400, 500, 5000};
     for (auto v : values)
     {
-        zone->addRPMSetPoint(v);
+        zone->addSetPoint(v);
     }
 
     // This will pull the maximum RPM setpoint request.
@@ -137,7 +137,7 @@
     EXPECT_EQ(5000, zone->getMaxRPMRequest());
 
     // Clear the values, so it'll choose the minimum thermal setpoint.
-    zone->clearRPMSetPoints();
+    zone->clearSetPoints();
 
     // This will go through the RPM set point values and grab the maximum.
     zone->determineMaxRPMRequest();
@@ -152,7 +152,7 @@
     std::vector<double> values = {100, 200, 300, 400, 500};
     for (auto v : values)
     {
-        zone->addRPMSetPoint(v);
+        zone->addSetPoint(v);
     }
 
     // This will pull the maximum RPM setpoint request.
@@ -121,7 +121,7 @@
 TEST_F(PidZoneTest, RpmSetPoints_AddMaxClear_BehaveAsExpected)
 {
-    // Tests addRPMSetPoint, clearRPMSetPoints, determineMaxRPMRequest
+    // Tests addSetPoint, clearSetPoints, determineMaxRPMRequest
     // and getMinThermalRPMSetpoint.
 